VerifierOptions

Struct VerifierOptions 

pub struct VerifierOptions {
    pub max_depth: usize,
    pub max_tables: usize,
    pub max_apparent_size: usize,
    pub ignore_missing_null_terminator: bool,
}

Fields

max_depth: usize

Maximum depth of nested tables allowed in a valid flatbuffer.

max_tables: usize

Maximum number of tables allowed in a valid flatbuffer.

max_apparent_size: usize

Maximum “apparent” size of the message if the Flatbuffer object DAG is expanded into a tree.

ignore_missing_null_terminator: bool

Ignore errors where a string is missing its null terminator. This is mostly a problem if the message will be sent to a client using old c-strings.